@@ -3,10 +3,11 @@
 
 .. versionadded:: 0.5.0
 """
-from ctypes import POINTER, Structure, c_double, c_int, c_size_t
+from ctypes import POINTER, Structure, c_bool, c_double, c_int, c_size_t
 from wand.cdefs.wandtypes import c_ssize_t, c_magick_real_t, c_magick_size_t
 
-__all__ = ('AffineMatrix', 'ChannelFeature', 'GeomertyInfo', 'KernelInfo',
+__all__ = ('AffineMatrix', 'CCMaxMetrics', 'CCObjectInfo', 'CCObjectInfo70A',
+           'CCObjectInfo710', 'ChannelFeature', 'GeometryInfo', 'KernelInfo',
            'MagickPixelPacket', 'PixelInfo', 'PointInfo', 'RectangleInfo')
 
 
@@ -60,8 +61,34 @@ class ChannelFeature(Structure):
                 ('maximum_correlation_coefficient', c_double * 4)]
 
 
-class GeomertyInfo(Structure):
-
+class GeometryInfo(Structure):
+    NoValue = 0x0000
+    XValue = 0x0001
+    XiValue = 0x0001
+    YValue = 0x0002
+    PsiValue = 0x0002
+    WidthValue = 0x0004
+    RhoValue = 0x0004
+    HeightValue = 0x0008
+    SigmaValue = 0x0008
+    ChiValue = 0x0010
+    XiNegative = 0x0020
+    XNegative = 0x0020
+    PsiNegative = 0x0040
+    YNegative = 0x0040
+    ChiNegative = 0x0080
+    PercentValue = 0x1000
+    AspectValue = 0x2000
+    NormalizeValue = 0x2000
+    LessValue = 0x4000
+    GreaterValue = 0x8000
+    MinimumValue = 0x10000
+    CorrelateNormalizeValue = 0x10000
+    AreaValue = 0x20000
+    DecimalValue = 0x40000
+    SeparatorValue = 0x80000
+    AspectRatioValue = 0x100000
+    AllValues = 0x7fffffff
     _fields_ = [('rho', c_double),
                 ('sigma', c_double),
                 ('xi', c_double),
@@ -147,6 +174,34 @@ class CCObjectInfo(Structure):
                 ('census', c_double)]
 
 
+CCMaxMetrics = 16
+
+
+class CCObjectInfo70A(Structure):
+    CCMaxMetrics = CCMaxMetrics
+    _fields_ = [('_id', c_ssize_t),
+                ('bounding_box', RectangleInfo),
+                ('color', PixelInfo),
+                ('centroid', PointInfo),
+                ('area', c_double),
+                ('census', c_double),
+                ('merge', c_bool),
+                ('metric', c_double * CCMaxMetrics)]
+
+
+class CCObjectInfo710(Structure):
+    CCMaxMetrics = CCMaxMetrics
+    _fields_ = [('_id', c_ssize_t),
+                ('bounding_box', RectangleInfo),
+                ('color', PixelInfo),
+                ('centroid', PointInfo),
+                ('area', c_double),
+                ('census', c_double),
+                ('merge', c_bool),
+                ('metric', c_double * CCMaxMetrics),
+                ('key', c_ssize_t)]
+
+
 # All this will change with IM7, so let's not implement this just yet.
 #
 # class ImageChannelStatistics(Structure):
